@@ -7,19 +7,17 @@ For information on getting started, see README.md.
 
 """
 
-from __future__ import absolute_import
 import sqlalchemy
 import sqlalchemy.orm.session
-from sqlalchemy import Index, Column, Integer, String, Float, ForeignKey, DateTime, Boolean, create_engine, orm
+from sqlalchemy import (Boolean, Column, DateTime, Float, ForeignKey, Index,
+                        Integer, String, and_, create_engine, or_, orm)
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import relationship, backref, sessionmaker, clear_mappers, deferred
-from sqlalchemy import and_, or_
+from sqlalchemy.orm import (backref, clear_mappers, deferred, relationship,
+                            sessionmaker)
 from sqlalchemy.orm.session import Session
 
-
-from . import core, log
+from . import core, log, properties
 from .core import *
 from .query import *
-from . import properties
 
-__version__ = '1.5.0'
+__version__ = '1.6.0'
