@@ -1,5 +1,5 @@
-from __future__ import absolute_import
-import sqlalchemy, sqlalchemy.exc
+import sqlalchemy
+import sqlalchemy.exc
 from sqlalchemy import Column, Integer, String
 
 from . import Base, get_default_session
@@ -92,8 +92,8 @@ def get_or_create_dictionary_item(session, name):
         # try to create it
         try:
             obj = DictionaryItem(name)
-            obj = session.merge(obj)
-            session.commit()
+            session.add(obj)
+            #session.commit()
         except sqlalchemy.exc.IntegrityError:
             session.rollback()
             obj = session.query(DictionaryItem).filter_by(text=name).first()
@@ -117,4 +117,4 @@ def _get_dict_cache_for_session(session):
 def get_lexicon(session):
     """Get a list of all strings known in the dictionary table"""
     dict_cache = _get_dict_cache_for_session(session)
-    return dict_cache.keys()
\ No newline at end of file
+    return dict_cache.keys()
