@@ -1,17 +1,11 @@
-from __future__ import absolute_import
-import weakref
 import numpy as np
+from sqlalchemy import Column, ForeignKey, Integer, orm, types
+from sqlalchemy.orm import Session, backref, relationship
 
-from sqlalchemy import Column, Integer, ForeignKey, orm, types
-from sqlalchemy.orm import relationship, backref, Session
-from sqlalchemy.ext.declarative import declared_attr
-
-from . import extraction_patterns
-from . import Base
-from . import creator
+from . import Base, creator, extraction_patterns
 from .dictionary import get_dict_id, get_or_create_dictionary_item
 from .timestep import TimeStep
-import six
+
 
 class UnsignedInteger(types.TypeDecorator):
     """Stores an unsigned int64 as a signed int64"""
@@ -41,12 +35,12 @@ class SimulationObjectBase(Base):
     finder_offset = Column(Integer) #index of halo within halo catalog, primary identifier used when reading catalog/simulation data
     timestep_id = Column(Integer, ForeignKey('timesteps.id'))
     timestep = relationship(TimeStep, backref=backref(
-        'objects', order_by=halo_number, cascade='all', lazy='dynamic'), cascade='save-update, merge')
+        'objects', order_by=halo_number, cascade_backrefs=False, lazy='dynamic'), cascade='')
     NDM = Column(Integer)
     NStar = Column(Integer)
     NGas = Column(Integer)
     creator = relationship(creator.Creator, backref=backref(
-        'halos', cascade='all', lazy='dynamic'), cascade='save-update')
+        'halos', cascade_backrefs=False, lazy='dynamic'), cascade='save-update')
     creator_id = Column(Integer, ForeignKey('creators.id'))
     object_typecode = Column(Integer, nullable=False,
                          name='halo_type') # name for backwards compatibility
@@ -62,8 +56,7 @@ class SimulationObjectBase(Base):
     def _all_subclasses(cls):
         for c in cls.__subclasses__():
             yield c
-            for c_sub in c._all_subclasses():
-                yield c_sub
+            yield from c._all_subclasses()
 
     @staticmethod
     def class_from_tag(match_tag):
@@ -75,7 +68,7 @@ class SimulationObjectBase(Base):
 
     @staticmethod
     def object_typecode_from_tag(match_tag):
-        if isinstance(match_tag, six.string_types):
+        if isinstance(match_tag, str):
             return SimulationObjectBase.class_from_tag(match_tag).__mapper_args__['polymorphic_identity']
         else:
             return match_tag
@@ -87,6 +80,27 @@ class SimulationObjectBase(Base):
                 return c.tag
         raise ValueError("Unknown object typecode %d",typecode)
 
+    @staticmethod
+    def typecode_and_number_from_human_identifier(identifier):
+        """Return object typecode and halo number given a human identification string or number
+
+        E.g. identifier = 5 -> typecode=0,
+        identifier = '1.5' -> typecode=1, number = 5
+        identifier = 'bh_5' -> typecode=1, number = 5
+        """
+        if isinstance(identifier, int):
+            object_typecode, object_number = 0, identifier
+        elif "." in identifier:
+            object_typecode, object_number = list(map(int, identifier.split(".")))
+        elif "_" in identifier:
+            object_typecode, object_number = identifier.split("_")
+            object_typecode = SimulationObjectBase.class_from_tag(object_typecode).__mapper_args__['polymorphic_identity']
+            object_number = int(object_number)
+        else:
+            object_typecode, object_number = 0, int(identifier)
+
+        return object_typecode, object_number
+
     def __init__(self, timestep, halo_number, finder_id, finder_offset, NDM, NStar, NGas, object_typecode=None):
         self.timestep = timestep
         self.halo_number = int(halo_number)
@@ -98,7 +112,7 @@ class SimulationObjectBase(Base):
         if object_typecode is not None:
             self.object_typecode = int(object_typecode)
         self.init_on_load()
-        self.creator_id = creator.get_creator_id()
+        self.creator = creator.get_creator(Session.object_session(timestep))
 
     @orm.reconstructor
     def init_on_load(self):
@@ -123,7 +137,7 @@ class SimulationObjectBase(Base):
         if not hasattr(self, "_handler"):
             self._handler = self.timestep.simulation.get_output_handler()
         return self._handler
-        
+
     @property
     def handler_class(self):
         if not hasattr(self, "_handler_class"):
@@ -256,20 +270,26 @@ class SimulationObjectBase(Base):
         X = self.properties.filter_by(name_id=key.id).first()
         if X is not None:
             X.data = obj
+            X.creator = creator.get_creator(session)
         else:
-            X = session.merge(HaloProperty(self, key, obj))
-        X.creator_id = creator.get_creator_id()
+            X = HaloProperty(self, key, obj)
+            X.creator = creator.get_creator(session)
+            session.add(X)
+        session.commit()
 
     def _setitem_one_halo(self, key, obj):
-        from . import Session, HaloLink
+        from . import HaloLink, Session
         session = Session.object_session(self)
         key = get_or_create_dictionary_item(session, key)
         X = self.links.filter_by(halo_from_id=self.id, relation_id=key.id).first()
         if X is None:
-            X = session.merge(HaloLink(self, obj, key))
-            X.creator_id = creator.get_creator_id()
+            X = HaloLink(self, obj, key)
+            X.creator = creator.get_creator(session)
+            session.add(X)
         else:
             X.halo_to = obj
+            X.creator = creator.get_creator(session)
+        session.commit()
 
     def _setitem_multiple_halos(self, key, obj):
         from . import Session
@@ -280,6 +300,7 @@ class SimulationObjectBase(Base):
         self.links.filter_by(halo_from_id=self.id, relation_id=key.id).delete()
         links = [HaloLink(self, halo_to, key) for halo_to in obj]
         session.add_all(links)
+        session.commit()
 
 
     def keys(self, getters = None):
@@ -333,10 +354,10 @@ class SimulationObjectBase(Base):
         :param strategy: The class to use to find the descendants (default relation_finding.MultiHopMajorDescendantsStrategy)
         """
         from .. import live_calculation
+        from .. import query as db_query
         from .. import relation_finding
         from .. import temporary_halolist as thl
         from . import Session
-        from .. import query as db_query
 
         nmax = kwargs.get('nmax',1000)
         strategy = kwargs.get('strategy', relation_finding.MultiHopMajorDescendantsStrategy)
@@ -405,7 +426,7 @@ class Halo(SimulationObjectBase):
     }
 
     tag = "halo"
-    
+
 class Tracker(SimulationObjectBase):
     __mapper_args__ = {
         'polymorphic_identity':3
@@ -414,7 +435,7 @@ class Tracker(SimulationObjectBase):
     tag = "tracker"
 
     def __init__(self, timestep, halo_number):
-        super(Tracker, self).__init__(timestep, halo_number, halo_number, halo_number, 0,0,0,
+        super().__init__(timestep, halo_number, halo_number, halo_number, 0,0,0,
                                  self.__mapper_args__['polymorphic_identity'])
 
     @property
@@ -442,7 +463,7 @@ class Group(SimulationObjectBase):
     tag = "group"
 
     def __init__(self, *args):
-        super(Group, self).__init__(*args)
+        super().__init__(*args)
         self.object_typecode = 2
 
 
@@ -456,7 +477,7 @@ class PhantomHalo(SimulationObjectBase):
     tag = "phantom"
 
     def __init__(self, timestep, halo_number, finder_id):
-        super(PhantomHalo, self).__init__(timestep, halo_number, finder_id, finder_id, 0,0,0,
+        super().__init__(timestep, halo_number, finder_id, finder_id, 0,0,0,
                                  self.__mapper_args__['polymorphic_identity'])
 
 
@@ -469,4 +490,4 @@ TimeStep.bhs = orm.relationship(BH, lazy='dynamic',viewonly=True,
 TimeStep.groups = orm.relationship(Group, lazy='dynamic',viewonly=True,
                                   order_by=Group.halo_number)
 TimeStep.phantoms = orm.relationship(PhantomHalo, lazy='dynamic',viewonly=True,
-                                  order_by=PhantomHalo.halo_number)
\ No newline at end of file
+                                  order_by=PhantomHalo.halo_number)
