@@ -1,11 +1,7 @@
-from __future__ import absolute_import
 from sqlalchemy.orm import relationship
 
-
-
-from .property import HaloProperty
 from .link import HaloLink
-
+from .property import HaloProperty
 
 
 def _initialise_halo_property_relationships():
@@ -13,13 +9,13 @@ def _initialise_halo_property_relationships():
     from ..halo import SimulationObjectBase
     from ..timestep import TimeStep
 
-    SimulationObjectBase.properties = relationship(HaloProperty, cascade='all', lazy='dynamic',
+    SimulationObjectBase.properties = relationship(HaloProperty, cascade='', lazy='dynamic',
                                    primaryjoin=(HaloProperty.halo_id == SimulationObjectBase.id) & (
                                        HaloProperty.deprecated == False),
                                    order_by=HaloProperty.id,
                                    uselist=True,overlaps='deprecated_properties')
 
-    SimulationObjectBase.deprecated_properties = relationship(HaloProperty, cascade='all', lazy='dynamic',
+    SimulationObjectBase.deprecated_properties = relationship(HaloProperty, cascade='', lazy='dynamic',
                                               primaryjoin=(HaloProperty.halo_id == SimulationObjectBase.id) & (
                                                   HaloProperty.deprecated == True),
                                               order_by=HaloProperty.id,
@@ -30,7 +26,7 @@ def _initialise_halo_property_relationships():
                                            HaloLink.halo_from_id == SimulationObjectBase.id),
                                        primaryjoin=(
                                            SimulationObjectBase.timestep_id == TimeStep.id),
-                                       cascade='none', lazy='dynamic',
+                                       cascade='', lazy='dynamic',
                                        order_by=HaloLink.id,
                                        viewonly=True)
 
@@ -40,7 +36,7 @@ def _initialise_halo_property_relationships():
                                      secondaryjoin=(
                                          HaloLink.halo_to_id == SimulationObjectBase.id),
                                      primaryjoin=(SimulationObjectBase.timestep_id == TimeStep.id),
-                                     cascade='none', lazy='dynamic',
+                                     cascade='', lazy='dynamic',
                                      order_by=HaloLink.id,
                                      viewonly=True)
 
@@ -51,4 +47,4 @@ def _initialise_halo_property_relationships():
     SimulationObjectBase.all_reverse_links = relationship(HaloLink, primaryjoin=(HaloLink.halo_to_id == SimulationObjectBase.id),
                                           viewonly=True, order_by=HaloLink.id)
 
-_initialise_halo_property_relationships()
\ No newline at end of file
+_initialise_halo_property_relationships()
