@@ -1,12 +1,12 @@
-from __future__ import absolute_import
-from __future__ import print_function
+import fnmatch
 import glob
 import os.path
-import fnmatch
+
+import numpy as np
+
 from .. import config
 from ..log import logger
-from six.moves import range
-import numpy as np
+from ..util.subclasses import find_subclasses
 
 
 def find(extension=None, mtd=None, ignore=None, basename="", patterns=[]):
@@ -32,7 +32,7 @@ def find(extension=None, mtd=None, ignore=None, basename="", patterns=[]):
     return set(out)
 
 
-class PatternBasedFileDiscovery(object):
+class PatternBasedFileDiscovery:
     """Provides methods for pattern-based file discovery, i.e. glob-ing for specific patterns of file in this
     folder and sub-folders"""
 
@@ -47,9 +47,12 @@ class PatternBasedFileDiscovery(object):
         handler_names = []
         handler_timestep_lengths = []
         base = os.path.join(config.base, basename)
-        if len(cls.__subclasses__()) == 0:
+
+        # Add all subclasses, sub-subclasses, sub-subclasses, ...
+        all_possible_handlers = find_subclasses(cls)
+        if not all_possible_handlers:
             return cls
-        all_possible_handlers = cls.__subclasses__()
+
         for possible_handler in all_possible_handlers:
             timesteps_detected = find(basename=base + "/", patterns=possible_handler.patterns)
             other_files_detected = find(basename=base+"/", patterns=possible_handler.auxiliary_file_patterns)
@@ -57,6 +60,7 @@ class PatternBasedFileDiscovery(object):
             handler_timestep_lengths.append(len(timesteps_detected)+len(other_files_detected))
         best_handler = handler_names[np.argmax(handler_timestep_lengths)]
         logger.debug("Detected best handler (of %d) is %s",len(all_possible_handlers), best_handler)
+
         return best_handler
 
     def enumerate_timestep_extensions(self):
@@ -73,4 +77,4 @@ class PatternBasedFileDiscovery(object):
         """Determine whether a named file can be loaded
 
         Override in child class to filter the pattern-based file matches"""
-        return True
\ No newline at end of file
+        return True
