@@ -1,16 +1,13 @@
-from __future__ import absolute_import
-
 yt = None # deferred import; occurs when a YtInputHandler is constructed
 
-from . import finding
-from . import HandlerBase
 from .. import config
 from ..log import logger
-from six.moves import range
+from . import HandlerBase, finding
+
 
 class YtInputHandler(finding.PatternBasedFileDiscovery, HandlerBase):
     def __init__(self, *args, **kwargs):
-        super(YtInputHandler, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         global yt
         import yt as yt_local
         yt = yt_local
@@ -50,11 +47,10 @@ class YtInputHandler(finding.PatternBasedFileDiscovery, HandlerBase):
         if object_typetag!="halo":
             return
         if self._can_enumerate_objects_from_statfile(ts_extension, object_typetag):
-            for X in self._enumerate_objects_from_statfile(ts_extension, object_typetag):
-                yield X
+            yield from self._enumerate_objects_from_statfile(ts_extension, object_typetag)
         else:
-            logger.warn("No halo statistics file found for timestep %r", ts_extension)
-            logger.warn(" => enumerating %ss directly using yt", object_typetag)
+            logger.warning("No halo statistics file found for timestep %r", ts_extension)
+            logger.warning(" => enumerating %ss directly using yt", object_typetag)
 
             catalogue, catalogue_data = self._load_halo_cat(ts_extension, object_typetag)
             num_objects = len(catalogue_data["halos", "virial_radius"])
@@ -92,4 +88,3 @@ class YtChangaAHFInputHandler(YtInputHandler):
                                                 hubble_constant = snapshot_file.hubble_constant)
         cat_data = cat.all_data()
         return cat, cat_data
-
