@@ -1,8 +1,11 @@
-from __future__ import absolute_import
-from .. import BuiltinFunction, FixedNumericInput
-import scipy, scipy.stats
 import math
+
 import numpy as np
+import scipy
+import scipy.stats
+
+from .. import BuiltinFunction, FixedNumericInput
+
 
 def single_array_smooth(ar_in, npix=5, one_tailed=False) :
     kern = scipy.stats.norm.pdf(np.linspace(-3,3,npix))
@@ -22,4 +25,4 @@ array_smooth.set_input_options(1, provide_proxy=True, assert_class = FixedNumeri
 @BuiltinFunction.register
 def element(halos, arrays, index):
     return [ar_i[index] if ar_i is not None else None for ar_i in arrays]
-element.set_input_options(1, provide_proxy=True, assert_class = FixedNumericInput)
\ No newline at end of file
+element.set_input_options(1, provide_proxy=True, assert_class = FixedNumericInput)
