@@ -1,6 +1,4 @@
-from __future__ import absolute_import
 from . import message
-from six.moves import range
 
 awaiting_barrier = None
 
