@@ -1,9 +1,9 @@
-from __future__ import absolute_import
-from .. import core
-from . import message
-from . import remote_import
 import sys
 
+from .. import core
+from . import message, remote_import
+
+
 class MessageRequestCreatorId(message.Message):
     def process(self):
         creator_id = core.creator.get_creator_id()
