@@ -1,15 +1,12 @@
-from __future__ import absolute_import
-from .. import core
-from ..util import consistent_collection
-
-from .multi_hop import MultiHopStrategy
-from .one_hop import HopStrategy
-from six.moves import range
-from six.moves import zip
-
 import sqlalchemy
 from sqlalchemy import orm
 
+from .. import core
+from ..util import consistent_collection
+from .multi_hop import MultiHopStrategy
+from .one_hop import HopStrategy
+
+
 class MultiSourceMultiHopStrategy(MultiHopStrategy):
     """A variant of MultiHopStrategy that finds halos corresponding to multiple start points.
 
@@ -50,7 +47,7 @@ class MultiSourceMultiHopStrategy(MultiHopStrategy):
         self._keep_only_highest_weights_per_hop = (directed == "forwards" or directed == "backwards")
         self._keep_only_highest_weights_per_hop&=self._return_only_highest_weights | (target is None)
 
-        super(MultiSourceMultiHopStrategy, self).__init__(halos_from[0], **kwargs)
+        super().__init__(halos_from[0], **kwargs)
         self._all_halo_from = halos_from
 
     def _infer_direction(self, halos_from, target):
@@ -78,10 +75,10 @@ class MultiSourceMultiHopStrategy(MultiHopStrategy):
         if self._should_halt():
             return 0
         else:
-            return super(MultiSourceMultiHopStrategy, self)._generate_next_level_prelim_links(from_nhops)
+            return super()._generate_next_level_prelim_links(from_nhops)
 
     def _supplement_halolink_query_with_filter(self, query, table=None):
-        query = super(MultiSourceMultiHopStrategy, self)._supplement_halolink_query_with_filter(query,table)
+        query = super()._supplement_halolink_query_with_filter(query,table)
 
         if self._keep_only_highest_weights_per_hop:
             query = self._extract_max_weight_rows_from_query(query, table)
@@ -183,4 +180,4 @@ class MultiSourceAllMajorDescendantsStrategy(MultiSourceMultiHopStrategy):
                          include_startpoint=True)
 
     def _should_halt(self):
-        return False
\ No newline at end of file
+        return False
