@@ -1,26 +1,24 @@
 #!/usr/bin/env python2.7
 
-from __future__ import absolute_import
-from __future__ import print_function
+import argparse
 import sys
+from textwrap import dedent
 
 import numpy as np
-import argparse
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 
 import tangos as db
-from tangos import all_simulations
-from tangos import core, config
-from tangos.core import Base, get_or_create_dictionary_item, \
-    Creator, Simulation, TimeStep, SimulationObjectBase, HaloProperty, HaloLink
+from tangos import all_simulations, config, core
+from tangos.core import (Base, Creator, HaloLink, HaloProperty, Simulation,
+                         SimulationObjectBase, TimeStep,
+                         get_or_create_dictionary_item)
 from tangos.core.simulation import SimulationProperty
 from tangos.core.tracking import TrackData
-from tangos.query import get_simulation, get_halo
 from tangos.input_handlers import get_named_handler_class
-from tangos.tools.add_simulation import SimulationAdderUpdater
 from tangos.log import logger
-from six.moves import input
+from tangos.query import get_halo, get_simulation
+from tangos.tools.add_simulation import SimulationAdderUpdater
 
 
 def add_simulation_timesteps(options):
@@ -61,7 +59,9 @@ def db_export(remote_db, *sims):
     _xcurrent_creator = core.creator.get_creator()
 
     core.set_default_session(ext_session)
-    core.set_creator(ext_session.merge(Creator()))
+    creator = Creator()
+    ext_session.add(creator)
+    core.set_creator(creator)
 
     _db_import_export(ext_session, int_session, *sims)
 
@@ -70,7 +70,7 @@ def db_export(remote_db, *sims):
 
 
 def _db_import_export(target_session, from_session, *sims):
-    external_to_internal_halo_id = {}
+    external_id_to_internal_halo = {}
     translated_halolink_ids = []
 
     if len(sims)==0:
@@ -79,7 +79,7 @@ def _db_import_export(target_session, from_session, *sims):
     for sim in sims:
         ext_sim = get_simulation(sim, from_session)
         sim = Simulation(ext_sim.basename)
-        sim = target_session.merge(sim)
+        target_session.add(sim)
         logger.info("Transferring simulation %s", ext_sim)
 
         halos_this_ts = []
@@ -103,7 +103,7 @@ def _db_import_export(target_session, from_session, *sims):
             ts.redshift = ts_ext.redshift
             ts.time_gyr = ts_ext.time_gyr
             ts.available = True
-            ts = target_session.merge(ts)
+            target_session.add(ts)
 
             halos_this_ts = []
 
@@ -119,55 +119,47 @@ def _db_import_export(target_session, from_session, *sims):
 
             for h in halos_this_ts:
                 assert h.id is not None and h.id > 0
-                external_to_internal_halo_id[h.external_id] = h.id
+                external_id_to_internal_halo[h.external_id] = h
 
             properties_this_ts = []
             logger.info("Transferring object properties for %s", ts_ext)
             for h_ext in ts_ext.objects:
-                h_new_id = external_to_internal_halo_id[h_ext.id]
+                h_new = external_id_to_internal_halo[h_ext.id]
                 for p_ext in h_ext.properties:
                     dic = get_or_create_dictionary_item(
                         target_session, p_ext.name.text)
                     dat = p_ext.data_raw
                     if dat is not None:
-                        p = HaloProperty(h_new_id, dic, dat)
-                        properties_this_ts.append(p)
+                        p = HaloProperty(h_new, dic, dat)
+                        target_session.add(p)
 
-            target_session.add_all(properties_this_ts)
             target_session.commit()
 
         for ts_ext in ext_sim.timesteps:
             logger.info("Transferring halolinks for timestep %s", ts_ext)
             sys.stdout.flush()
             _translate_halolinks(
-                target_session, ts_ext.links_from, external_to_internal_halo_id, translated_halolink_ids)
+                target_session, ts_ext.links_from, external_id_to_internal_halo, translated_halolink_ids)
             _translate_halolinks(
-                target_session, ts_ext.links_to, external_to_internal_halo_id, translated_halolink_ids)
+                target_session, ts_ext.links_to, external_id_to_internal_halo, translated_halolink_ids)
             target_session.commit()
 
         logger.info("Done")
 
 
 
-def _translate_halolinks(target_session, halolinks, external_to_internal_halo_id, translated):
+def _translate_halolinks(target_session, halolinks, external_id_to_internal_halo, translated):
     for hl_ext in halolinks:
         if hl_ext.id in translated:
             continue
 
         dic = get_or_create_dictionary_item(
             target_session, hl_ext.relation.text)
-        hl_new = target_session.merge(HaloLink(None, None, dic))
+        hl_new = HaloLink(external_id_to_internal_halo[hl_ext.halo_from_id],
+                          external_id_to_internal_halo[hl_ext.halo_to_id],
+                          dic)
 
-        try:
-            hl_new.halo_from_id = external_to_internal_halo_id[
-                hl_ext.halo_from_id]
-        except KeyError:
-            continue
-
-        try:
-            hl_new.halo_to_id = external_to_internal_halo_id[hl_ext.halo_to_id]
-        except KeyError:
-            continue
+        target_session.add(hl_new)
 
         translated.append(hl_ext.id)
 
@@ -176,25 +168,61 @@ def flag_duplicates_deprecated(opts):
 
     session = db.core.get_default_session()
 
-    print("unmark all:",session.execute("update haloproperties set deprecated=0").rowcount)
-    print("      mark:",session.execute("update haloproperties set deprecated=1 where id in (SELECT min(id) FROM haloproperties GROUP BY halo_id, name_id HAVING COUNT(*)>1 ORDER BY halo_id, name_id)").rowcount)
+    print("unmark all properties:", session.execute("update haloproperties set deprecated=0").rowcount)
+    print("duplicate properties marked:", session.execute("update haloproperties set deprecated=1 where id in (SELECT min(id) FROM haloproperties GROUP BY halo_id, name_id HAVING COUNT(*)>1 ORDER BY halo_id, name_id)").rowcount)
+
+    print("unmark all links:", session.execute("update halolink set deprecated=0").rowcount)
+    print("duplicate links marked:", session.execute("update halolink set deprecated=1 where id in (SELECT min(id) FROM halolink GROUP BY halo_from_id, halo_to_id, relation_id HAVING COUNT(*)>1 ORDER BY halo_from_id, halo_to_id, weight)").rowcount)
 
     session.commit()
 
-def remove_duplicates(opts):
-    flag_duplicates_deprecated(None)
-    count = 1
-    while count>0:
-        # Order of name_id, halo_id in group clause below is important for optimisation - halo_id, name_id
-        # does *not* match the index.
-        count = db.core.get_default_session().execute("delete from haloproperties where haloproperties.id in "
-                                                 "(SELECT min(id) FROM haloproperties "
-                                                 "    GROUP BY name_id, halo_id HAVING COUNT(halo_id)>1);").rowcount
-        if count>0 :
-            print("Deleted %d rows"%count)
-            print("  checking for further duplicates...")
-    print("Done")
-    db.core.get_default_session().commit()
+def remove_duplicates(options):
+
+    session = db.core.get_default_session()
+
+    # Note: the MySQL documentation states that “You cannot delete from a table and
+    # select from the same table in a subquery.”. You can however circumvent this
+    # limitation by creating an implicit temporary table.
+    # See https://dev.mysql.com/doc/refman/5.6/en/delete.html
+    # and https://stackoverflow.com/a/45498/2601223
+    # Another approach would have been to use an inner join but unfortunately
+    # SQLite does not support them in deletes, so we have to resort to this approach.
+    # With MySQL 5.7.6 onwards, this implicit temporary tables may be optimized away
+    # leading to the very same error we are trying to avoid. This can be fixed by
+    # setting the optimizer_switch off for the query.
+    # See https://dev.mysql.com/doc/relnotes/mysql/5.7/en/news-5-7-6.html#mysqld-5-7-6-optimizer
+    dialect = session.connection().engine.dialect.dialect_description.split("+")[0].lower()
+    if dialect == 'mysql':
+        session.execute("SET @__optimizations = @@SESSION.optimizer_switch")
+        session.execute("SET @@SESSION.optimizer_switch = 'derived_merge=off'")
+
+    count = session.execute(dedent("""
+        DELETE FROM haloproperties
+        WHERE id NOT IN (
+            SELECT * FROM (
+                SELECT MAX(id)
+                FROM haloproperties
+                GROUP BY halo_id, name_id
+            ) as t
+        )
+    """)).rowcount
+
+    count_links = session.execute(dedent("""
+        DELETE FROM halolink
+        WHERE id NOT IN (
+            SELECT * FROM (
+                SELECT MAX(id)
+                FROM halolink
+                GROUP BY halo_from_id, halo_to_id, relation_id
+            ) as t
+        )
+    """)).rowcount
+
+    if dialect == 'mysql':
+        session.execute("SET @@SESSION.optimizer_switch = @__optimizations")
+    print("Deleted %d rows" % count)
+    print("Deleted %d links" % count_links)
+    session.commit()
 
 
 
@@ -356,8 +384,8 @@ def grep_remove_runs(opts):
     print(""">>> type "yes" to continue""")
 
     if input(":").lower() == "yes":
-        for r, run in enumerate(matching_runs):
-            print('Removing run ',r+1,' of ',len(matching_runs))
+        for r, run in enumerate(matching_runs[::-1]):
+            print(f'Removing run {run.id}')
             _erase_run_content(run)
         print("Done")
     else:
@@ -402,8 +430,8 @@ def list_available_properties(options):
         else:
             return "live".center(15)
 
-    longest_class_name = max([len(format_class_name(cl)) for cl in properties.all_property_classes()])
-    print("%s | %s | %s" % ("name".rjust(30), "handler".center(15), "property class"))
+    longest_class_name = max(len(format_class_name(cl)) for cl in properties.all_property_classes())
+    print("{} | {} | {}".format("name".rjust(30), "handler".center(15), "property class"))
     print("-"*30+"-+-"+"-"*15+"-+-"+"-"*longest_class_name)
     for p in all_properties:
         classes = properties.all_providing_classes(p)
@@ -478,13 +506,13 @@ def get_argument_parser_and_subparsers():
     subparse_greprun.set_defaults(func=grep_run_id)
     subparse_greprun.add_argument("query", type=str,
                                      help="The sub-string to search for in the command line")
-                                     
+
     subparse_grepruninfo = subparse.add_parser("grep-runs",
                                           help="List details of runs matching command line input")
     subparse_grepruninfo.set_defaults(func=grep_run_info)
     subparse_grepruninfo.add_argument("query", type=str,
                                      help="The sub-string to search for in the command line")
-                                                              
+
     subparse_grepremove = subparse.add_parser("grep-remove",
                                            help="Remove runs matching command line input")
     subparse_grepremove.set_defaults(func=grep_remove_runs)
@@ -498,7 +526,7 @@ def get_argument_parser_and_subparsers():
     subparse_remruns.add_argument("sims", help="The path to the simulation folder relative to the database folder")
     subparse_remruns.set_defaults(func=rem_simulation_timesteps)
      """
-    
+
     subparse_import = subparse.add_parser("import",
                                           help="Import one or more simulations from another sqlite file")
     subparse_import.add_argument("file", type=str, help="The filename of the sqlite file from which to import")
@@ -509,10 +537,10 @@ def get_argument_parser_and_subparsers():
 
 
     subparse_deprecate = subparse.add_parser("flag-duplicates",
-                                             help="Flag old copies of properties (if they are present)")
+                                             help="Flag old copies of properties and duplicate links (if they are present)")
     subparse_deprecate.set_defaults(func=flag_duplicates_deprecated)
     subparse_deprecate = subparse.add_parser("remove-duplicates",
-                                             help="Remove old copies of properties (if they are present)")
+                                             help="Remove old copies of properties and duplicate links (if they are present)")
     subparse_deprecate.set_defaults(func=remove_duplicates)
 
     subparse_rollback = subparse.add_parser("rollback", help="Remove database updates")
