@@ -1,11 +1,11 @@
-from __future__ import absolute_import
-from . import core
-from sqlalchemy import Column, Table, Integer
-import sqlalchemy
+import contextlib
 import random
 import string
-import contextlib
-from six.moves import range
+
+import sqlalchemy
+from sqlalchemy import Column, Integer, Table
+
+from . import core
 
 _temp_sessions = {}
 
@@ -39,7 +39,7 @@ def _insert_into_temp_halolist(table, ids):
     else:
         connection.execute(
             table.insert(),
-            *[{'halo_id': id} for id in ids]
+            [{'halo_id': id} for id in ids]
         )
 
 def _get_session_for(table):
