@@ -1,12 +1,12 @@
-from __future__ import absolute_import
-from __future__ import print_function
-from sqlalchemy.orm import Session
 import numpy as np
-from .core import get_or_create_dictionary_item, SimulationObjectBase, HaloLink, TrackData
-from . import query
-import six
+from sqlalchemy.orm import Session
+
 import tangos.parallel_tasks as parallel_tasks
-from six.moves import zip
+
+from . import query
+from .core import (HaloLink, SimulationObjectBase, TrackData,
+                   get_or_create_dictionary_item)
+
 
 def generate_tracker_halo_link_if_not_present(halo_1, halo_2, dict_obj=None, weight=1.0):
     assert isinstance(halo_1, SimulationObjectBase)
@@ -17,8 +17,8 @@ def generate_tracker_halo_link_if_not_present(halo_1, halo_2, dict_obj=None, wei
 
     if dict_obj is None:
         dict_obj = get_or_create_dictionary_item(session, "tracker")
-    #print halo_1.id,"->",halo_2.id
-    session.merge(HaloLink(halo_1,halo_2,dict_obj,weight))
+
+    session.add(HaloLink(halo_1,halo_2,dict_obj,weight))
 
 def get_trackers(sim):
     trackers = sim.trackers.all()
@@ -63,7 +63,7 @@ def generate_tracker_halo_links(sim, session):
     session.commit()
 
 def new(for_simulation, using_particles):
-    if isinstance(for_simulation, six.string_types):
+    if isinstance(for_simulation, str):
         for_simulation = query.get_simulation(for_simulation)
     tracker = TrackData(for_simulation)
     use_iord = 'iord' in using_particles.loadable_keys()
@@ -73,4 +73,4 @@ def new(for_simulation, using_particles):
     tracker.create_objects()
     tracker.create_links()
     session.commit()
-    return tracker.halo_number
\ No newline at end of file
+    return tracker.halo_number
