@@ -1,10 +1,10 @@
 import csv
-from six import StringIO
+from io import StringIO
 
 # CSV renderer based on pyramid example
 # https://docs.pylonsproject.org/projects/pyramid-cookbook/en/latest/templates/customrenderers.html
 
-class CSVRenderer(object):
+class CSVRenderer:
     def __init__(self, info):
         pass
 
@@ -27,4 +27,4 @@ class CSVRenderer(object):
         writer.writerow(value.get('header', []))
         writer.writerows(value.get('rows', []))
 
-        return fout.getvalue()
\ No newline at end of file
+        return fout.getvalue()
