@@ -1,6 +1,9 @@
 from pyramid.view import view_config
+
+from ... import live_calculation, properties
 from ...core import dictionary
-from ... import properties, live_calculation
+
+
 @view_config(route_name='autocomplete_words', renderer='json')
 def autocomplete_words(request):
     dictionary_items = list(dictionary.get_lexicon(request.dbsession))
